aboutsummaryrefslogtreecommitdiff
path: root/lib/ldap.c
diff options
context:
space:
mode:
authorDaniel Stenberg <daniel@haxx.se>2007-11-24 23:18:21 +0000
committerDaniel Stenberg <daniel@haxx.se>2007-11-24 23:18:21 +0000
commit162c039e9d0b19bd98244e35e6265b2ff978c085 (patch)
treed84fb75ecd04283d4d060289a35b77a1af8e6d4d /lib/ldap.c
parent13648f8ccda6f99674ac407640474634e856804c (diff)
reqdata doesn't exist anymore and the path moved to the UrlState struct
Diffstat (limited to 'lib/ldap.c')
-rw-r--r--lib/ldap.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/lib/ldap.c b/lib/ldap.c
index d3cee5189..4f5625c40 100644
--- a/lib/ldap.c
+++ b/lib/ldap.c
@@ -555,7 +555,7 @@ static bool unescape_elements (void *data, LDAPURLDesc *ludp)
*
* <hostname> already known from 'conn->host.name'.
* <port> already known from 'conn->remote_port'.
* extract the rest from 'conn->data->reqdata.path+1'. All fields are optional.
* e.g.
* ldap://<hostname>:<port>/?<attributes>?<scope>?<filter>
* yields ludp->lud_dn = "".
@@ -568,8 +568,8 @@ static int _ldap_url_parse2 (const struct connectdata *conn, LDAPURLDesc *ludp)
int i;
if(!conn->data ||
- !conn->data->reqdata.path ||
- conn->data->reqdata.path[0] != '/' ||
+ !conn->data->state.path ||
+ conn->data->state.path[0] != '/' ||
!checkprefix(conn->protostr, conn->data->change.url))
return LDAP_INVALID_SYNTAX;
@@ -579,7 +579,7 @@ static int _ldap_url_parse2 (const struct connectdata *conn, LDAPURLDesc *ludp)
/* parse DN (Distinguished Name).
*/
- ludp->lud_dn = strdup(conn->data->reqdata.path+1);
+ ludp->lud_dn = strdup(conn->data->state.path+1);
if(!ludp->lud_dn)
return LDAP_NO_MEMORY;
@@ -555,7 +555,7 @@ static bool unescape_elements (void *data, LDAPURLDesc *ludp)
* <hostname> already known from 'conn->host.name'.
* <port> already known from 'conn->remote_port'.
- * extract the rest from 'conn->data->reqdata.path+1'. All fields are optional.
+ * extract the rest from 'conn->data->state.path+1'. All fields are optional.
* e.g.
* ldap://<hostname>:<port>/?<attributes>?<scope>?<filter>